==> WASP_1.4.1.tar.gz: WASP/R/sampledata.R <==
#'@title Sample data: Rainfall station data over Sydney region
#'@description A dataset containing 732 rows (data length) and 15 columns (stations).
#'
#'@docType data
#'@keywords datasets
#'@name rain.mon
#'@usage data(rain.mon)
NULL

#'@title Sample data: NCEP reanalysis data averaged over Sydney region
#'@description A dataset containing 720 rows (data length) and 7 columns (atmospheric variables).
#'@docType data
#'@keywords datasets
#'@name obs.mon
#'@usage data(obs.mon)
NULL

#'@title Sample data: Australia map
#'@description A dataset containing the Australia map.
#'
#'@docType data
#'@keywords datasets
#'@name aus.coast
#'@usage data(aus.coast)
NULL

#'@title Sample data: AWAP rainfall data over Australia
#'@description A dataset containing 1320 rows (data length) and 252 columns (grids).
#'
#'@docType data
#'@keywords datasets
#'@name data.AWAP.2.5
#'@usage data(data.AWAP.2.5)
NULL

#'@title Sample data: Index of AWAP grids with no missing data
#'@description A dataset containing 145 numbers.
#'
#'@docType data
#'@keywords datasets
#'@name Ind_AWAP.2.5
#'@usage data(Ind_AWAP.2.5)
NULL

#'@title Sample data: Latitude and longitude of AWAP grids
#'@description A dataset containing 252 rows (grids) and 2 columns (lat and lon).
#'
#'@docType data
#'@keywords datasets
#'@name lat_lon.2.5
#'@usage data(lat_lon.2.5)
NULL

#'@title Sample data: Climate indices strongly influencing Australia climate
#'@description A dataset containing 1332 rows (data length) and 6 columns (indices).
#'@docType data
#'@keywords datasets
#'@name data.CI
#'@usage data(data.CI)
NULL

#'@title Sample data: Standardized Precipitation Index with 12 month accumulation period.
#'@description A dataset containing 1200 rows (data length) and 252 columns.
#'
#'@docType data
#'@keywords datasets
#'@name SPI.12
#'@usage data(SPI.12)
NULL

#'@title Sample data: Sinewave model 1 (SW1):\deqn{ x_{t}= sin(2pi*f*t)+eps}
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'
#'@docType data
#'@keywords datasets
#'@name data.SW1
#'@usage data(data.SW1)
NULL

#'@title Sample data: Sinewave model 3 (SW3): \deqn{ x_{t}= \sum_{i=1}^3 sin(2pi*f_{i}*t)+eps}
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'
#'@docType data
#'@keywords datasets
#'@name data.SW3
#'@usage data(data.SW3)
NULL

#'@title Sample data: Hysteresis loop
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'
#'@docType data
#'@keywords datasets
#'@name data.HL
#'@usage data(data.HL)
NULL

==> WASP_1.4.4.tar.gz: WASP/R/sampledata.R <==
#'@title Sample data: Rainfall station data over Sydney region
#'@description A dataset containing 732 rows (data length) and 15 columns (stations).
#'
#'@docType data
#'@keywords datasets
#'@name rain.mon
#'@usage data(rain.mon)
NULL

#'@title Sample data: NCEP reanalysis data averaged over Sydney region
#'@description A dataset containing 720 rows (data length) and 7 columns (atmospheric variables).
#'@docType data
#'@keywords datasets
#'@name obs.mon
#'@usage data(obs.mon)
NULL

#'@title Sample data: Australia map
#'@description A dataset containing the Australia map.
#'
#'@docType data
#'@keywords datasets
#'@name aus.coast
#'@usage data(aus.coast)
NULL

#'@title Sample data: AWAP rainfall data over Australia
#'@description A dataset containing 1320 rows (data length) and 252 columns (grids).
#'
#'@docType data
#'@keywords datasets
#'@name data.AWAP.2.5
#'@usage data(data.AWAP.2.5)
NULL

#'@title Sample data: Index of AWAP grids with no missing data
#'@description A dataset containing 145 numbers.
#'
#'@docType data
#'@keywords datasets
#'@name Ind_AWAP.2.5
#'@usage data(Ind_AWAP.2.5)
NULL

#'@title Sample data: Latitude and longitude of AWAP grids
#'@description A dataset containing 252 rows (grids) and 2 columns (lat and lon).
#'
#'@docType data
#'@keywords datasets
#'@name lat_lon.2.5
#'@usage data(lat_lon.2.5)
NULL

#'@title Sample data: Climate indices strongly influencing Australia climate
#'@description A dataset containing 1332 rows (data length) and 6 columns (indices).
#'@docType data
#'@keywords datasets
#'@name data.CI
#'@usage data(data.CI)
NULL

#'@title Sample data: Standardized Precipitation Index with 12 month accumulation period.
#'@description A dataset containing 1200 rows (data length) and 252 columns.
#'
#'@docType data
#'@keywords datasets
#'@name SPI.12
#'@usage data(SPI.12)
NULL

#'@title Sample data: Sinewave model 1 (SW1)
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'The Sinewave model 1 (SW1) is defined as:
#'\deqn{x_{t}= sin(2pi*f*t)+eps}
#'
#'@docType data
#'@keywords datasets
#'@name data.SW1
#'@usage data(data.SW1)
NULL

#'@title Sample data: Sinewave model 3 (SW3)
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'The Sinewave model 3 (SW3) is defined as:
#'\deqn{x_{t}= \sum_{i=1}^3 sin(2pi*f_{i}*t)+eps}
#'
#'@docType data
#'@keywords datasets
#'@name data.SW3
#'@usage data(data.SW3)
NULL

#'@title Sample data: Hysteresis loop
#'@description A dataset containing 3 lists: a vector of response (x), a matrix of 9 potential predictors (dp) with each column containing one potential predictor, and a vector of true predictor numbers.
#'
#'@docType data
#'@keywords datasets
#'@name data.HL
#'@usage data(data.HL)
NULL
